@@ -18,11 +18,11 @@ import shutil
 import csv
 import pkg_resources
 # mine
-import .preprocess_dataset
-import .features
-import .create_pfiles
-import .create_model
-from .HandwrittenData import HandwrittenData
+from . import preprocess_dataset
+from . import features
+from . import create_pfiles
+from . import create_model
+from HandwrittenData import HandwrittenData
 
 
 def print_status(total, current, start_time=None):
